// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDEVPLATFORM_VERSION_H
#define KDEVPLATFORM_VERSION_H

#define KDEVPLATFORM_VERSION_STRING "5.7.211203"
#define KDEVPLATFORM_VERSION_MAJOR 5
#define KDEVPLATFORM_VERSION_MINOR 7
#define KDEVPLATFORM_VERSION_PATCH 211203
#define KDEVPLATFORM_VERSION ((5<<16)|(7<<8)|(211203))

#endif
