// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDEVELOP_VERSION_H
#define KDEVELOP_VERSION_H

#define KDEVELOP_VERSION_STRING "5.7.211203"
#define KDEVELOP_VERSION_MAJOR 5
#define KDEVELOP_VERSION_MINOR 7
#define KDEVELOP_VERSION_PATCH 211203
#define KDEVELOP_VERSION ((5<<16)|(7<<8)|(211203))

#endif
